==> lxqt-config_2.1.1.orig.tar.xz: lxqt-config-2.1.1/lxqt-config-locale/translations/lxqt-config-locale_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gion&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;tals dels reglatges</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Tria e règlas de classament&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Exemples</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Paramètres del format modificats</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Volètz enregistrar las modificacions&#x202f;? S’aplicaràn a la connexion venenta.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Imperial Reialme-Unit</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>Imperial Estats-Units</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metric</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>Paramètres regionals de LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Paramètres regionals</translation>
    </message>
</context>
</TS>

==> lxqt-config-2.3.0.tar.xz: lxqt-config-2.3.0/lxqt-config-locale/translations/lxqt-config-locale_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gion&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;tals dels reglatges</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Tria e règlas de classament&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Exemples</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation>Non definit</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation>Actual : </translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Paramètres del format modificats</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Volètz enregistrar las modificacions&#x202f;? S’aplicaràn a la connexion venenta.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Imperial Reialme-Unit</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>Imperial Estats-Units</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metric</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>Paramètres regionals de LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Paramètres regionals</translation>
    </message>
</context>
</TS>
